from .sql2gee import SQL2GEE
from pkg_resources import get_distribution

__version__ = get_distribution('sql2gee').version